[![PyPI version](https://img.shields.io/pypi/v/calibr8)](https://pypi.org/project/calibr8)
[![pipeline](https://github.com/jubiotech/calibr8/workflows/pipeline/badge.svg)](https://github.com/jubiotech/calibr8/actions)
[![coverage](https://codecov.io/gh/jubiotech/calibr8/branch/master/graph/badge.svg)](https://codecov.io/gh/jubiotech/calibr8)
[![documentation](https://readthedocs.org/projects/calibr8/badge/?version=latest)](https://calibr8.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/306862348.svg)](https://zenodo.org/badge/latestdoi/306862348)


# `calibr8`
This package provides templates and functions for performing likelihood-based calibration modeling.
To see implementation examples & excercises, you can go to [notebooks/](notebooks).

# Installation
`calibr8` is released on [PyPI](https://pypi.org/project/calibr8/):

```
pip install calibr8
```
# Documentation
Read the package documentation [here](https://calibr8.readthedocs.io/en/latest/?badge=latest).

# Usage and Citing
`calibr8` is licensed under the [GNU Affero General Public License v3.0](https://github.com/michaelosthege/calibr8/blob/master/LICENSE).

Head over to Zenodo to [generate a BibTeX citation](https://doi.org/10.5281/zenodo.4127012) for the latest release.

Please cite the paper as:

*Helleckes & Osthege et al. (2021). Bayesian calibration, process modeling and uncertainty quantification in biotechnology. bioRxiv. https://doi.org/10.1101/2021.06.30.450546*

```
@article {calibr8,
	author = {Helleckes, Laura Marie and Osthege, Michael and Wiechert, Wolfgang and von Lieres, Eric and Oldiges, Marco},
	title = {Bayesian calibration, process modeling and uncertainty quantification in biotechnology},
	elocation-id = {2021.06.30.450546},
	year = {2021},
	doi = {10.1101/2021.06.30.450546},
	publisher = {Cold Spring Harbor Laboratory},
	URL = {https://www.biorxiv.org/content/early/2021/07/03/2021.06.30.450546},
	eprint = {https://www.biorxiv.org/content/early/2021/07/03/2021.06.30.450546.full.pdf},
	journal = {bioRxiv}
}
```
